@@ -30,6 +30,9 @@ except ImportError:
 LOGGER = logging.getLogger(__name__)
 
 
+# Reference of Numeric Annotation Glyphs:
+# https://en.wikipedia.org/wiki/Numeric_Annotation_Glyphs
+
 NAG_NULL = 0
 
 NAG_GOOD_MOVE = 1
@@ -59,9 +62,13 @@ NAG_ACTIVE_POSITION = 12
 NAG_UNCLEAR_POSITION = 13
 NAG_WHITE_SLIGHT_ADVANTAGE = 14
 NAG_BLACK_SLIGHT_ADVANTAGE = 15
+NAG_WHITE_MODERATE_ADVANTAGE = 16
+NAG_BLACK_MODERATE_ADVANTAGE = 17
+NAG_WHITE_DECISIVE_ADVANTAGE = 18
+NAG_BLACK_DECISIVE_ADVANTAGE = 19
 
-# TODO: Add more constants for example from
-# https://en.wikipedia.org/wiki/Numeric_Annotation_Glyphs
+NAG_WHITE_ZUGZWANG = 22
+NAG_BLACK_ZUGZWANG = 23
 
 NAG_WHITE_MODERATE_COUNTERPLAY = 132
 NAG_BLACK_MODERATE_COUNTERPLAY = 133
@@ -72,6 +79,8 @@ NAG_BLACK_MODERATE_TIME_PRESSURE = 137
 NAG_WHITE_SEVERE_TIME_PRESSURE = 138
 NAG_BLACK_SEVERE_TIME_PRESSURE = 139
 
+NAG_NOVELTY = 146
+
 
 TAG_REGEX = re.compile(r"^\[([A-Za-z0-9_]+)\s+\"(.*)\"\]\s*$")
 
