@@ -41,7 +41,10 @@ class SuicideBoard(chess.Board):
     def pin_mask(self, color, square):
         return chess.BB_ALL
 
-    def _attacked_for_king(self, path):
+    def _attacked_for_king(self, path, occupied):
+        return False
+
+    def _castling_uncovers_rank_attack(self, rook_bb, king_to):
         return False
 
     def is_check(self):
@@ -240,14 +243,18 @@ class AtomicBoard(chess.Board):
 
         return False
 
-    def _attacked_for_king(self, path):
+    def _attacked_for_king(self, path, occupied):
         # Can castle onto attacked squares if they are connected to the
         # enemy king.
         enemy_kings = self.kings & self.occupied_co[not self.turn]
         for enemy_king in chess.scan_forward(enemy_kings):
             path &= ~chess.BB_KING_ATTACKS[enemy_king]
 
-        return super(AtomicBoard, self)._attacked_for_king(path)
+        return super(AtomicBoard, self)._attacked_for_king(path, occupied)
+
+    def _castling_uncovers_rank_attack(self, rook_bb, king_to):
+        return (not chess.BB_KING_ATTACKS[king_to] & self.kings & self.occupied_co[not self.turn] and
+                super(AtomicBoard, self)._castling_uncovers_rank_attack(rook_bb, king_to))
 
     def _kings_connected(self):
         white_kings = self.kings & self.occupied_co[chess.WHITE]
@@ -677,21 +684,24 @@ class CrazyhouseBoard(chess.Board):
     def is_seventyfive_moves(self):
         return False
 
-    def is_zeroing(self, move):
-        return False
+    def is_irreversible(self, move):
+        backrank = chess.BB_RANK_1 if self.turn == chess.WHITE else chess.BB_RANK_8
+        castling_rights = self.clean_castling_rights() & backrank
+        return (castling_rights and chess.BB_SQUARES[move.from_square] & self.kings & ~self.promoted or
+                castling_rights & chess.BB_SQUARES[move.from_square] or
+                castling_rights & chess.BB_SQUARES[move.to_square])
 
     def legal_drop_squares_mask(self):
-        king_bb = self.kings & self.occupied_co[self.turn]
-        if not king_bb:
+        king = self.king(self.turn)
+        if king is None:
             return ~self.occupied
 
-        king_square = chess.msb(king_bb)
-        king_attackers = self.attackers_mask(not self.turn, king_square)
+        king_attackers = self.attackers_mask(not self.turn, king)
 
         if not king_attackers:
             return ~self.occupied
         elif chess.popcount(king_attackers) == 1:
-            return chess.BB_BETWEEN[king_square][chess.msb(king_attackers)] & ~self.occupied
+            return chess.BB_BETWEEN[king][chess.msb(king_attackers)] & ~self.occupied
         else:
             return chess.BB_VOID
 
